package com.ruoyi.invest.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.uuid.IdUtils;
import com.ruoyi.invest.domain.TProjectCompany;
import com.ruoyi.invest.mapper.TProjectCompanyMapper;
import com.ruoyi.invest.service.ITProjectCompanyService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * 项目公司信息Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-02-22
 */
@Service
public class TProjectCompanyServiceImpl implements ITProjectCompanyService
{
    @Autowired
    private TProjectCompanyMapper tProjectCompanyMapper;

    /**
     * 查询项目公司信息
     * 
     * @param id 项目公司信息主键
     * @return 项目公司信息
     */
    @Override
    public TProjectCompany selectTProjectCompanyById(String id)
    {
        return tProjectCompanyMapper.selectTProjectCompanyById(id);
    }

    /**
     * 查询项目公司信息列表
     * 
     * @param tProjectCompany 项目公司信息
     * @return 项目公司信息
     */
    @Override
    public List<TProjectCompany> selectTProjectCompanyList(TProjectCompany tProjectCompany)
    {
        return tProjectCompanyMapper.selectTProjectCompanyList(tProjectCompany);
    }

    /**
     * 新增项目公司信息
     * 
     * @param tProjectCompany 项目公司信息
     * @return 结果
     */
    @Override
    public int insertTProjectCompany(TProjectCompany tProjectCompany)
    {
        tProjectCompany.setCreateTime(DateUtils.getNowDate());
        return tProjectCompanyMapper.insertTProjectCompany(tProjectCompany);
    }

    /**
     * 修改项目公司信息
     * 
     * @param tProjectCompany 项目公司信息
     * @return 结果
     */
    @Override
    public int updateTProjectCompany(TProjectCompany tProjectCompany)
    {
        tProjectCompany.setUpdateTime(DateUtils.getNowDate());
        return tProjectCompanyMapper.updateTProjectCompany(tProjectCompany);
    }

    /**
     * 批量删除项目公司信息
     * 
     * @param ids 需要删除的项目公司信息主键
     * @return 结果
     */
    @Override
    public int deleteTProjectCompanyByIds(String[] ids)
    {
        return tProjectCompanyMapper.deleteTProjectCompanyByIds(ids);
    }

    /**
     * 删除项目公司信息信息
     * 
     * @param id 项目公司信息主键
     * @return 结果
     */
    @Override
    public int deleteTProjectCompanyById(String id)
    {
        return tProjectCompanyMapper.deleteTProjectCompanyById(id);
    }

    /**
     * 批量删除项目公司信息(修改del_flag状态)
     *
     * @param ids 需要删除的项目公司信息主键
     * @return 结果
     */
    @Override
    public int updateTProjectCompanyByIds(String[] ids) {
        return tProjectCompanyMapper.updateTProjectCompanyByIds(ids);
    }

    /**
     * 根据项目ID查询项目公司信息
     * @param projectPoolId
     * @return
     */
    @Override
    public TProjectCompany selectTProjectCompanyByProjectPoolId(String projectPoolId) {
        return tProjectCompanyMapper.selectTProjectCompanyByProjectPoolId(projectPoolId);
    }
}
